clustering
----------

.. currentmodule:: eqcorrscan.utils.clustering
.. automodule:: eqcorrscan.utils.clustering

    .. comment to end block

    Classes & Functions
    -------------------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       svd
       svd_to_stream
       catalog_cluster
       cluster
       corr_cluster
       cross_chan_correlation
       dist_mat_km
       distance_matrix
       empirical_svd
       extract_detections
       group_delays
       re_thresh_csv
       space_time_cluster

    .. comment to end block
